pub enum TzError {
InvalidId(NulError),
Io(Error),
}Expand description
An error getting a timezone from the system database.
Variants
InvalidId(NulError)
The given timezone ID string contained a NUL byte.
Io(Error)
There was an error allocating a timezone with the given ID.